@@ -18,6 +18,7 @@
 # 
 
 __tarball__ = """
+  anyelf
   capsnamespkg
   depends
   directoryname
@@ -46,9 +47,9 @@ __pkgbuild__ = """
   badbackups
   capsnames
   carch
+  checksums
   invalidstartdir
   license
-  md5sums
   pkgname
   rpath
   sfurl
