@@ -17,7 +17,7 @@
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
 
-import pacman, re
+import re
 
 class package:
 	def short_name(self):
@@ -29,8 +29,9 @@ class package:
 	def analyze(self, pkginfo, tar):
 		arrayvars = ['arch', 'license', 'depends', 'makedepends',
 			 'optdepends', 'provides', 'conflicts' , 'replaces',
-			 'backup', 'source', 'noextract', 'md5sums']
-		ret = [[],[],[]]
+			 'backup', 'source', 'noextract', 'md5sums',
+			 'sha1sums', 'sha256sums', 'sha384sums', 'sha512sums']
+		ret = [[], [], []]
 		for i in pkginfo.pkgbuild:
 			m = re.match('\s*(.*)\s*=\s*(.*)\n', i)
 			for j in arrayvars:
