@@ -17,7 +17,7 @@
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
 
-import pacman,re
+import re
 
 class package:
 	def short_name(self):
@@ -27,7 +27,7 @@ class package:
 	def prereq(self):
 		return ""
 	def analyze(self, pkginfo, tar):
-		ret = [[],[],[]]
+		ret = [[], [], []]
 		if re.search('[A-Z]', pkginfo.name) != None:
 			ret[0].append(("package-name-in-uppercase", ()))
 		return ret
