@@ -17,7 +17,7 @@
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
 
-import pacman, re
+import re
 
 class package:
 	def short_name(self):
@@ -27,8 +27,8 @@ class package:
 	def prereq(self):
 		return ""
 	def analyze(self, pkginfo, tar):
-		ret = [[],[],[]]
-		arches = ['i686','i586','x86_64']
+		ret = [[], [], []]
+		arches = ['i686', 'i586', 'x86_64']
 		archmatch = re.compile('%s' % '|'.join(arches))
 		# Match an arch=(i686) line
 		archline = re.compile('arch=\w*(%s)' % '|'.join(arches))
