@@ -18,13 +18,9 @@
 #
 
 import os
-import re
-from Namcap.util import is_elf
+from Namcap.util import is_elf, clean_filename
 
-process = lambda s: re.search("/tmp/namcap\.[0-9]*/(.*)", s).group(1)
-
-
-def scanelf(invalid_elffiles,dirname,names):
+def scanelf(invalid_elffiles, dirname, names):
 	'''Method to scan for ELF files in invalid directories'''
 
 	# Valid directories for ELF files
@@ -37,14 +33,13 @@ def scanelf(invalid_elffiles,dirname,names):
 		# Checking for ELF files
 		if is_elf(file_path):
 			for f in valid_dirs:
-				if ('/' + process(file_path)).startswith(f):
+				if ('/' + clean_filename(file_path)).startswith(f):
 					valid_dir_found = True
 					break 
-					
+
 			if not valid_dir_found:
-				invalid_elffiles.append(process(file_path))
-					
-				
+				invalid_elffiles.append(clean_filename(file_path))
+
 
 class package:
 	def short_name(self):
@@ -54,7 +49,7 @@ class package:
 	def prereq(self):
 		return "extract"
 	def analyze(self, pkginfo, data):
-		ret = [[],[],[]]
+		ret = [[], [], []]
 		invalid_elffiles = []
 		
 		os.path.walk(data, scanelf, invalid_elffiles)		
