@@ -17,7 +17,7 @@
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
 
-import pacman, re
+import re
 
 class package:
 	def short_name(self):
@@ -29,9 +29,10 @@ class package:
 	def analyze(self, pkginfo, tar):
 		stdvars = ['arch', 'license', 'depends', 'makedepends',
 				 'provides', 'conflicts' , 'replaces', 'backup',
-				 'source', 'noextract', 'md5sums', 'pkgname',
+				 'source', 'noextract', 'md5sums', 'sha1sums',
+				 'sha256sums', 'sha384sums', 'sha512sums', 'pkgname',
 				 'pkgver', 'pkgrel', 'pkgdesc', 'url', 'install']
-		ret = [[],[],[]]
+		ret = [[], [], []]
 		for i in pkginfo.pkgbuild:
 			m = re.match('[\s]*([^\s=]*)\s*=', i)
 			if m:
