@@ -17,9 +17,6 @@
 #   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
 
-import os
-import tarfile
-
 class package:
 	def short_name(self):
 		return "lots-of-docs"
@@ -28,7 +25,7 @@ class package:
 	def prereq(self):
 		return "tar"
 	def analyze(self, pkginfo, tar):
-		ret = [[],[],[]]
+		ret = [[], [], []]
 		if hasattr(pkginfo, 'name'):
 			if pkginfo.name.endswith('-doc'):
 				return ret
